@@ -8,11 +8,12 @@ import kkpyutil as util
 class PathMan:
     def __init__(self, cwd=None):
         self.root = cwd or os.getcwd()
-        self.premakePluginLua = self.find_premake_plugin_lua_in_ancestor()
+        self.premakePluginLua = self.find_premake_plugin_lua_in_ancestor_and_update_root()
+        os.chdir(self.root)
         self.pluginName = self.parse_plugin_name()
         self.configDir = osp.join(self.root, '.wpe')
 
-    def find_premake_plugin_lua_in_ancestor(self):
+    def find_premake_plugin_lua_in_ancestor_and_update_root(self):
         premake_script_filename = 'PremakePlugin.lua'
         while self.root:
             lua = osp.join(self.root, premake_script_filename)
@@ -30,4 +31,3 @@ class PathMan:
         for line in lines:
             if matched := re.match(name_define_pattern, line):
                 return matched.group().split('"')[1]
-
